@@ -84,11 +84,11 @@ def _struct_extract_sql(self, expression):
 
 
 class DuckDB(Dialect):
-    DATE_FORMAT = "'%Y-%M-%d'"
-    TIME_FORMAT = "'%Y-%M-%d %H:%M:%S'"
+    DATE_FORMAT = "'%Y-%m-%d'"
+    TIME_FORMAT = "'%Y-%m-%d %H:%M:%S'"
 
     def _unix_to_time(self, expression):
-        return f"EPOCH_MS(CAST(({self.sql(expression, 'this')} AS BIGINT) * 1000))"
+        return f"TO_TIMESTAMP(CAST({self.sql(expression, 'this')} AS BIGINT))"
 
     transforms = {
         exp.ApproxDistinct: _approx_count_distinct_sql,
@@ -121,6 +121,7 @@ class DuckDB(Dialect):
         'REGEXP_MATCHES': lambda args: exp.RegexLike(this=args[0], expression=args[1]),
         'STRFTIME': lambda args: exp.TimeToStr(this=args[0], format=args[1]),
         'STRPTIME': lambda args: exp.StrToTime(this=args[0], format=args[1]),
+        'TO_TIMESTAMP': lambda args: exp.TimeStrToTime(this=args[0]),
     }
 
 
@@ -296,7 +297,7 @@ class Presto(Dialect):
         exp.FileFormat: _fileformat_sql,
         exp.If: _if_sql,
         exp.Initcap: _initcap_sql,
-        exp.JSONPath: lambda self, e: f"JSON_EXTRACT({self.sql(e, 'this')}, {self.sql(e, 'path')})",
+        exp.JSONPath: lambda self, e: f"JSON_EXTRACT_SCALAR({self.sql(e, 'this')}, {self.sql(e, 'path')})",
         exp.RegexLike: lambda self, e: f"REGEXP_LIKE({self.sql(e, 'this')}, {self.sql(e, 'expression')})",
         exp.StrPosition: _str_position_sql,
         exp.StrToTime: lambda self, e: f"DATE_PARSE({self.sql(e, 'this')}, {self.sql(e, 'format')})",
@@ -324,6 +325,7 @@ class Presto(Dialect):
         'DATE_PARSE': lambda args: exp.StrToTime(this=args[0], format=args[1]),
         'FROM_UNIXTIME': lambda args: exp.UnixToTime(this=args[0]),
         'JSON_EXTRACT': lambda args: exp.JSONPath(this=args[0], path=args[1]),
+        'JSON_EXTRACT_SCALAR': lambda args: exp.JSONPath(this=args[0], path=args[1]),
         'REGEXP_LIKE': lambda args: exp.RegexLike(this=args[0], expression=args[1]),
         'STRPOS': lambda args: exp.StrPosition(this=args[0], substr=args[1]),
         'TO_UNIXTIME': lambda args: exp.TimeToUnix(this=args[0]),
